# Feature
<!-- Please add a brief description of the feature -->

## Checklist
- [ ] Entry added to `CHANGELOG.md`.
- [ ] Docs are updated.
- [ ] [Corp docs](https://github.com/Datadog/documentation) are updated (if applicable).
- [ ] Added to the correct milestone.

### Testing
- [ ] Tests are run against all relevant library versions (or confirm that the relevant versions are already being tested in `tox.ini`)

